@@ -53,9 +53,9 @@ siz_t bli_packm_init
 
 	bszid_t   bmult_id_m;
 	bszid_t   bmult_id_n;
-	bool_t    does_invert_diag;
-	bool_t    rev_iter_if_upper;
-	bool_t    rev_iter_if_lower;
+	bool      does_invert_diag;
+	bool      rev_iter_if_upper;
+	bool      rev_iter_if_lower;
 	pack_t    schema;
 	//packbuf_t pack_buf_type;
 	siz_t     size_needed;
@@ -261,7 +261,7 @@ siz_t bli_packm_init_pack
 			bli_obj_toggle_uplo( p );
 	}
 
-	// If we are packing micro-panels, mark P as dense. Otherwise, we are
+	// If we are packing micropanels, mark P as dense. Otherwise, we are
 	// probably being called in the context of a level-2 operation, in
 	// which case we do not want to overwrite the uplo field of P (inherited
 	// from A) with BLIS_DENSE because that information may be needed by
@@ -368,28 +368,28 @@ siz_t bli_packm_init_pack
 		// default (logical) blocksize multiple in the m dimension.
 		m_panel = bmult_m_def;
 
-		// The "column stride" of a row panel packed object is interpreted as
-		// the column stride WITHIN a panel. Thus, this is equal to the
-		// packing (storage) blocksize multiple (which may be equal to the
-		// default (logical) blocksize multiple.
+		// The "column stride" of a row-micropanel packed object is interpreted
+		// as the column stride WITHIN a micropanel. Thus, this is equal to the
+		// packing (storage) blocksize multiple, which may be equal to the
+		// default (logical) blocksize multiple).
 		cs_p = bmult_m_pack;
 
-		// The "row stride" of a row panel packed object is interpreted
-		// as the row stride WITHIN a panel. Thus, it is unit.
+		// The "row stride" of a row-micropanel packed object is interpreted
+		// as the row stride WITHIN a micropanel. Thus, it is unit.
 		rs_p = 1;
 
-		// The "panel stride" of a panel packed object is interpreted as the
-		// distance between the (0,0) element of panel k and the (0,0)
+		// The "panel stride" of a micropanel packed object is interpreted as
+		// the distance between the (0,0) element of panel k and the (0,0)
 		// element of panel k+1. We use the padded width computed above to
 		// allow for zero-padding (if necessary/desired) along the far end
-		// of each panel (ie: the right edge of the matrix). Zero-padding
-		// can also occur along the long edge of the last panel if the m
+		// of each micropanel (ie: the right edge of the matrix). Zero-padding
+		// can also occur along the long edge of the last micropanel if the m
 		// dimension of the matrix is not a whole multiple of MR.
 		ps_p = cs_p * n_p_pad;
 
-		// As a general rule, we don't want panel strides to be odd. This
+		// As a general rule, we don't want micropanel strides to be odd. This
 		// is primarily motivated by our desire to support interleaved 3m
-		// micro-panels, in which case we have to scale the panel stride
+		// micropanels, in which case we have to scale the panel stride
 		// by 3/2. That division by 2 means the numerator (prior to being
 		// scaled by 3) must be even.
 		if ( bli_is_odd( ps_p ) ) ps_p += 1;
@@ -399,7 +399,7 @@ siz_t bli_packm_init_pack
 
 		// Here, we adjust the panel stride, if necessary. Remember: ps_p is
 		// always interpreted as being in units of the datatype of the object
-		// which is not necessarily how the micro-panels will be stored. For
+		// which is not necessarily how the micropanels will be stored. For
 		// interleaved 3m, we will increase ps_p by 50%, and for ro/io/rpi,
 		// we halve ps_p. Why? Because the macro-kernel indexes in units of
 		// the complex datatype. So these changes "trick" it into indexing
@@ -418,11 +418,11 @@ siz_t bli_packm_init_pack
 			// If it is indeed odd, we nudge it higher.
 			if ( bli_is_odd( ps_p ) ) ps_p += 1;
 
-			// Despite the fact that the packed micro-panels will contain
+			// Despite the fact that the packed micropanels will contain
 			// real elements, the panel stride that we store in the obj_t
 			// (which is passed into the macro-kernel) needs to be in units
 			// of complex elements, since the macro-kernel will index through
-			// micro-panels via complex pointer arithmetic for trmm/trsm.
+			// micropanels via complex pointer arithmetic for trmm/trsm.
 			// Since the indexing "increment" will be twice as large as each
 			// actual stored element, we divide the panel_stride by 2.
 			ps_p = ps_p / 2;
@@ -431,10 +431,10 @@ siz_t bli_packm_init_pack
 		// Set the imaginary stride (in units of fundamental elements) for
 		// 3m and 4m (separated or interleaved). We use ps_p_orig since
 		// that variable tracks the number of real part elements contained
-		// within each micro-panel of the source matrix. Therefore, this
+		// within each micropanel of the source matrix. Therefore, this
 		// is the number of real elements that must be traversed before
-		// reaching the imaginary part (3mi/4mi) of the packed micro-panel,
-		// or the real part of the next micro-panel (3ms).
+		// reaching the imaginary part (3mi/4mi) of the packed micropanel,
+		// or the real part of the next micropanel (3ms).
 		if      ( bli_is_3mi_packed( schema ) ) is_p = ps_p_orig;
 		else if ( bli_is_4mi_packed( schema ) ) is_p = ps_p_orig;
 		else if ( bli_is_3ms_packed( schema ) ) is_p = ps_p_orig * ( m_p_pad / m_panel );
@@ -461,28 +461,29 @@ siz_t bli_packm_init_pack
 		// default (logical) blocksize multiple in the n dimension.
 		n_panel = bmult_n_def;
 
-		// The "row stride" of a column panel packed object is interpreted as
-		// the row stride WITHIN a panel. Thus, this is equal to the
+		// The "row stride" of a column-micropanel packed object is interpreted
+		// as the row stride WITHIN a micropanel. Thus, this is equal to the
 		// packing (storage) blocksize multiple (which may be equal to the
 		// default (logical) blocksize multiple.
 		rs_p = bmult_n_pack;
 
-		// The "column stride" of a column panel packed object is interpreted
-		// as the column stride WITHIN a panel. Thus, it is unit.
+		// The "column stride" of a column-micropanel packed object is
+		// interpreted as the column stride WITHIN a micropanel. Thus, it is
+		// unit.
 		cs_p = 1;
 
-		// The "panel stride" of a panel packed object is interpreted as the
-		// distance between the (0,0) element of panel k and the (0,0)
+		// The "panel stride" of a micropanel packed object is interpreted as
+		// the distance between the (0,0) element of panel k and the (0,0)
 		// element of panel k+1. We use the padded length computed above to
 		// allow for zero-padding (if necessary/desired) along the far end
-		// of each panel (ie: the bottom edge of the matrix). Zero-padding
-		// can also occur along the long edge of the last panel if the n
+		// of each micropanel (ie: the bottom edge of the matrix). Zero-padding
+		// can also occur along the long edge of the last micropanel if the n
 		// dimension of the matrix is not a whole multiple of NR.
 		ps_p = m_p_pad * rs_p;
 
-		// As a general rule, we don't want panel strides to be odd. This
+		// As a general rule, we don't want micropanel strides to be odd. This
 		// is primarily motivated by our desire to support interleaved 3m
-		// micro-panels, in which case we have to scale the panel stride
+		// micropanels, in which case we have to scale the panel stride
 		// by 3/2. That division by 2 means the numerator (prior to being
 		// scaled by 3) must be even.
 		if ( bli_is_odd( ps_p ) ) ps_p += 1;
@@ -492,7 +493,7 @@ siz_t bli_packm_init_pack
 
 		// Here, we adjust the panel stride, if necessary. Remember: ps_p is
 		// always interpreted as being in units of the datatype of the object
-		// which is not necessarily how the micro-panels will be stored. For
+		// which is not necessarily how the micropanels will be stored. For
 		// interleaved 3m, we will increase ps_p by 50%, and for ro/io/rpi,
 		// we halve ps_p. Why? Because the macro-kernel indexes in units of
 		// the complex datatype. So these changes "trick" it into indexing
@@ -511,11 +512,11 @@ siz_t bli_packm_init_pack
 			// If it is indeed odd, we nudge it higher.
 			if ( bli_is_odd( ps_p ) ) ps_p += 1;
 
-			// Despite the fact that the packed micro-panels will contain
+			// Despite the fact that the packed micropanels will contain
 			// real elements, the panel stride that we store in the obj_t
 			// (which is passed into the macro-kernel) needs to be in units
 			// of complex elements, since the macro-kernel will index through
-			// micro-panels via complex pointer arithmetic for trmm/trsm.
+			// micropanels via complex pointer arithmetic for trmm/trsm.
 			// Since the indexing "increment" will be twice as large as each
 			// actual stored element, we divide the panel_stride by 2.
 			ps_p = ps_p / 2;
@@ -524,10 +525,10 @@ siz_t bli_packm_init_pack
 		// Set the imaginary stride (in units of fundamental elements) for
 		// 3m and 4m (separated or interleaved). We use ps_p_orig since
 		// that variable tracks the number of real part elements contained
-		// within each micro-panel of the source matrix. Therefore, this
+		// within each micropanel of the source matrix. Therefore, this
 		// is the number of real elements that must be traversed before
-		// reaching the imaginary part (3mi/4mi) of the packed micro-panel,
-		// or the real part of the next micro-panel (3ms).
+		// reaching the imaginary part (3mi/4mi) of the packed micropanel,
+		// or the real part of the next micropanel (3ms).
 		if      ( bli_is_3mi_packed( schema ) ) is_p = ps_p_orig;
 		else if ( bli_is_4mi_packed( schema ) ) is_p = ps_p_orig;
 		else if ( bli_is_3ms_packed( schema ) ) is_p = ps_p_orig * ( n_p_pad / n_panel );
