@@ -45,7 +45,7 @@ void PASTEMAC(ch,varname) \
        uplo_t          uploc, \
        conj_t          conjc, \
        pack_t          schema, \
-       bool_t          invdiag, \
+       bool            invdiag, \
        dim_t           m_panel, \
        dim_t           n_panel, \
        dim_t           m_panel_max, \
@@ -299,8 +299,8 @@ void PASTEMAC(ch,varname) \
 { \
 	doff_t  diagoffc_abs; \
 	dim_t   j; \
-	bool_t  row_stored; \
-	bool_t  col_stored; \
+	bool    row_stored; \
+	bool    col_stored; \
 \
 \
 	/* Create flags to incidate row or column storage. Note that the
@@ -528,7 +528,7 @@ void PASTEMAC(ch,varname) \
        uplo_t          uploc, \
        conj_t          conjc, \
        pack_t          schema, \
-       bool_t          invdiag, \
+       bool            invdiag, \
        dim_t           m_panel, \
        dim_t           n_panel, \
        dim_t           m_panel_max, \
