@@ -40,7 +40,7 @@
 \
 void PASTEMAC(ch,opname) \
      ( \
-       bool_t           will_pack, \
+       bool             will_pack, \
        packbuf_t        pack_buf_type, \
        dim_t            m, \
        dim_t            k, \
@@ -174,7 +174,7 @@ INSERT_GENTFUNC_BASIC0( packm_sup_init_mem_a )
 \
 void PASTEMAC(ch,opname) \
      ( \
-       bool_t           did_pack, \
+       bool             did_pack, \
        rntm_t* restrict rntm, \
        mem_t*  restrict mem, \
        thrinfo_t* restrict thread  \
@@ -212,7 +212,7 @@ INSERT_GENTFUNC_BASIC0( packm_sup_finalize_mem_a )
 \
 void PASTEMAC(ch,opname) \
      ( \
-       bool_t           will_pack, \
+       bool             will_pack, \
        stor3_t          stor_id, \
        pack_t* restrict schema, \
        dim_t            m, \
@@ -311,7 +311,7 @@ INSERT_GENTFUNC_BASIC0( packm_sup_init_a )
 \
 void PASTEMAC(ch,opname) \
      ( \
-       bool_t           will_pack, \
+       bool             will_pack, \
        packbuf_t        pack_buf_type, \
        stor3_t          stor_id, \
        trans_t          transc, \
