@@ -93,6 +93,12 @@ void bli_l3_thrinfo_free
        thrinfo_t* thread
      );
 
+void bli_l3_sup_thrinfo_free
+     (
+       rntm_t*    rntm,
+       thrinfo_t* thread
+     );
+
 // -----------------------------------------------------------------------------
 
 void bli_l3_thrinfo_create_root
@@ -104,6 +110,20 @@ void bli_l3_thrinfo_create_root
        thrinfo_t** thread
      );
 
+void bli_l3_sup_thrinfo_create_root
+     (
+       dim_t       id,
+       thrcomm_t*  gl_comm,
+       rntm_t*     rntm,
+       thrinfo_t** thread
+     );
+
+void bli_l3_sup_thrinfo_update_root
+     (
+       rntm_t*    rntm,
+       thrinfo_t* thread
+     );
+
 void bli_l3_thrinfo_print_gemm_paths
      (
        thrinfo_t** threads
