@@ -46,20 +46,23 @@
   #define __arm__
 #endif
 
-#ifndef BLIS_CONFIGURETIME_CPUID
-  #include "blis.h"
-#else
+#ifdef BLIS_CONFIGURETIME_CPUID
+  #define BLIS_INLINE static
   #define BLIS_EXPORT_BLIS
   #include "bli_system.h"
   #include "bli_type_defs.h"
   #include "bli_cpuid.h"
   #include "bli_arch.h"
+#else
+  #include "blis.h"
 #endif
 
 // -----------------------------------------------------------------------------
 
 #if defined(__x86_64__) || defined(_M_X64) || defined(__i386) || defined(_M_IX86)
 
+#include "cpuid.h"
+
 arch_t bli_cpuid_query_id( void )
 {
 	uint32_t vendor, family, model, features;
@@ -148,7 +151,7 @@ arch_t bli_cpuid_query_id( void )
 
 // -----------------------------------------------------------------------------
 
-bool_t bli_cpuid_is_skx
+bool bli_cpuid_is_skx
      (
        uint32_t family,
        uint32_t model,
@@ -188,7 +191,7 @@ bool_t bli_cpuid_is_skx
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_knl
+bool bli_cpuid_is_knl
      (
        uint32_t family,
        uint32_t model,
@@ -207,7 +210,7 @@ bool_t bli_cpuid_is_knl
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_haswell
+bool bli_cpuid_is_haswell
      (
        uint32_t family,
        uint32_t model,
@@ -224,7 +227,7 @@ bool_t bli_cpuid_is_haswell
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_sandybridge
+bool bli_cpuid_is_sandybridge
      (
        uint32_t family,
        uint32_t model,
@@ -239,7 +242,7 @@ bool_t bli_cpuid_is_sandybridge
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_penryn
+bool bli_cpuid_is_penryn
      (
        uint32_t family,
        uint32_t model,
@@ -257,7 +260,7 @@ bool_t bli_cpuid_is_penryn
 
 // -----------------------------------------------------------------------------
 
-bool_t bli_cpuid_is_zen2
+bool bli_cpuid_is_zen2
      (
        uint32_t family,
        uint32_t model,
@@ -276,7 +279,7 @@ bool_t bli_cpuid_is_zen2
 
 	// Finally, check for specific models:
 	// - 0x30-0xff (THIS NEEDS UPDATING)
-	const bool_t is_arch
+	const bool is_arch
 	=
 	( 0x30 <= model && model <= 0xff );
 
@@ -285,7 +288,7 @@ bool_t bli_cpuid_is_zen2
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_zen
+bool bli_cpuid_is_zen
      (
        uint32_t family,
        uint32_t model,
@@ -304,7 +307,7 @@ bool_t bli_cpuid_is_zen
 
 	// Finally, check for specific models:
 	// - 0x00-0xff (THIS NEEDS UPDATING)
-	const bool_t is_arch
+	const bool is_arch
 	=
 	( 0x00 <= model && model <= 0xff );
 
@@ -313,7 +316,7 @@ bool_t bli_cpuid_is_zen
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_excavator
+bool bli_cpuid_is_excavator
      (
        uint32_t family,
        uint32_t model,
@@ -332,7 +335,7 @@ bool_t bli_cpuid_is_excavator
 
 	// Finally, check for specific models:
 	// - 0x60-0x7f
-	const bool_t is_arch
+	const bool is_arch
 	=
 	( 0x60 <= model && model <= 0x7f );
 
@@ -341,7 +344,7 @@ bool_t bli_cpuid_is_excavator
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_steamroller
+bool bli_cpuid_is_steamroller
      (
        uint32_t family,
        uint32_t model,
@@ -360,7 +363,7 @@ bool_t bli_cpuid_is_steamroller
 
 	// Finally, check for specific models:
 	// - 0x30-0x3f
-	const bool_t is_arch
+	const bool is_arch
 	=
 	( 0x30 <= model && model <= 0x3f );
 
@@ -369,7 +372,7 @@ bool_t bli_cpuid_is_steamroller
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_piledriver
+bool bli_cpuid_is_piledriver
      (
        uint32_t family,
        uint32_t model,
@@ -389,7 +392,7 @@ bool_t bli_cpuid_is_piledriver
 	// Finally, check for specific models:
 	// - 0x02
 	// - 0x10-0x1f
-	const bool_t is_arch
+	const bool is_arch
 	=
 	model == 0x02 || ( 0x10 <= model && model <= 0x1f );
 
@@ -398,7 +401,7 @@ bool_t bli_cpuid_is_piledriver
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_bulldozer
+bool bli_cpuid_is_bulldozer
      (
        uint32_t family,
        uint32_t model,
@@ -417,7 +420,7 @@ bool_t bli_cpuid_is_bulldozer
 	// Finally, check for specific models:
 	// - 0x00
 	// - 0x01
-	const bool_t is_arch
+	const bool is_arch
 	=
 	( model == 0x00 || model == 0x01 );
 
@@ -489,7 +492,7 @@ arch_t bli_cpuid_query_id( void )
 	return BLIS_ARCH_GENERIC;
 }
 
-bool_t bli_cpuid_is_thunderx2
+bool bli_cpuid_is_thunderx2
      (
        uint32_t family,
        uint32_t model,
@@ -504,7 +507,7 @@ bool_t bli_cpuid_is_thunderx2
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_cortexa57
+bool bli_cpuid_is_cortexa57
      (
        uint32_t family,
        uint32_t model,
@@ -519,7 +522,7 @@ bool_t bli_cpuid_is_cortexa57
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_cortexa53
+bool bli_cpuid_is_cortexa53
      (
        uint32_t family,
        uint32_t model,
@@ -534,7 +537,7 @@ bool_t bli_cpuid_is_cortexa53
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_cortexa15
+bool bli_cpuid_is_cortexa15
      (
        uint32_t family,
        uint32_t model,
@@ -549,7 +552,7 @@ bool_t bli_cpuid_is_cortexa15
 	return TRUE;
 }
 
-bool_t bli_cpuid_is_cortexa9
+bool bli_cpuid_is_cortexa9
      (
        uint32_t family,
        uint32_t model,
