@@ -44,36 +44,36 @@
 	BLIS_ARCH_CORTEXA9  = 12,
 	BLIS_ARCH_GENERIC   = 13
   } arch_t;
-  typedef uint64_t bool_t;
+  typedef uint64_t bool;
   #define bli_abort abort
 #endif
 
 #ifndef BLIS_CPUID_H
 #define BLIS_CPUID_H
 
-arch_t   bli_cpuid_query_id( void );
+arch_t bli_cpuid_query_id( void );
 
 // Intel
-bool_t   bli_cpuid_is_skx( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_knl( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_haswell( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_sandybridge( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_penryn( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_skx( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_knl( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_haswell( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_sandybridge( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_penryn( uint32_t family, uint32_t model, uint32_t features );
 
 // AMD
-bool_t   bli_cpuid_is_zen2( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_zen( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_excavator( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_steamroller( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_piledriver( uint32_t family, uint32_t model, uint32_t features );
-bool_t   bli_cpuid_is_bulldozer( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_zen2( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_zen( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_excavator( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_steamroller( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_piledriver( uint32_t family, uint32_t model, uint32_t features );
+bool bli_cpuid_is_bulldozer( uint32_t family, uint32_t model, uint32_t features );
 
 // ARM
-bool_t   bli_cpuid_is_thunderx2( uint32_t model, uint32_t part, uint32_t features );
-bool_t   bli_cpuid_is_cortexa57( uint32_t model, uint32_t part, uint32_t features );
-bool_t   bli_cpuid_is_cortexa53( uint32_t model, uint32_t part, uint32_t features );
-bool_t   bli_cpuid_is_cortexa15( uint32_t model, uint32_t part, uint32_t features );
-bool_t   bli_cpuid_is_cortexa9( uint32_t model, uint32_t part, uint32_t features );
+bool bli_cpuid_is_thunderx2( uint32_t model, uint32_t part, uint32_t features );
+bool bli_cpuid_is_cortexa57( uint32_t model, uint32_t part, uint32_t features );
+bool bli_cpuid_is_cortexa53( uint32_t model, uint32_t part, uint32_t features );
+bool bli_cpuid_is_cortexa15( uint32_t model, uint32_t part, uint32_t features );
+bool bli_cpuid_is_cortexa9( uint32_t model, uint32_t part, uint32_t features );
 
 uint32_t bli_cpuid_query( uint32_t* family, uint32_t* model, uint32_t* features );
 
@@ -116,7 +116,7 @@ uint32_t bli_cpuid_query( uint32_t* family, uint32_t* model, uint32_t* features
 
 */
 
-static bool_t bli_cpuid_has_features( uint32_t have, uint32_t want )
+BLIS_INLINE bool bli_cpuid_has_features( uint32_t have, uint32_t want )
 {
     return ( have & want ) == want;
 }
@@ -125,7 +125,9 @@ static bool_t bli_cpuid_has_features( uint32_t have, uint32_t want )
 
 #if defined(__x86_64__) || defined(_M_X64) || defined(__i386) || defined(_M_IX86)
 
-#include "cpuid.h"
+// cpuid.h is now #included in bli_cpuid.c instead of here. See issue #393
+// for more information why this move was made.
+//#include "cpuid.h"
 
 void get_cpu_name( char *cpu_name );
 int  vpu_count( void );
