@@ -70,7 +70,7 @@ void bli_thread_range_sub
        thrinfo_t* thread,
        dim_t      n,
        dim_t      bf,
-       bool_t     handle_edge_low,
+       bool       handle_edge_low,
        dim_t*     start,
        dim_t*     end
      )
@@ -301,7 +301,7 @@ dim_t bli_thread_range_width_l
        dim_t  bf,
        dim_t  bf_left,
        double area_per_thr,
-       bool_t handle_edge_low
+       bool   handle_edge_low
      )
 {
 	dim_t width;
@@ -510,7 +510,7 @@ siz_t bli_thread_range_weighted_sub
        dim_t               m,
        dim_t               n,
        dim_t               bf,
-       bool_t              handle_edge_low,
+       bool                handle_edge_low,
        dim_t*     restrict j_start_thr,
        dim_t*     restrict j_end_thr
      )
@@ -667,7 +667,7 @@ siz_t bli_thread_range_mdim
 
 	blksz_t* bmult  = bli_cntx_get_bmult( bszid, cntx );
 	obj_t*   x;
-	bool_t   use_weighted;
+	bool     use_weighted;
 
 	// Use the operation family to choose the one of the two matrices
 	// being partitioned that potentially has structure, and also to
@@ -726,7 +726,7 @@ siz_t bli_thread_range_ndim
 
 	blksz_t* bmult  = bli_cntx_get_bmult( bszid, cntx );
 	obj_t*   x;
-	bool_t   use_weighted;
+	bool     use_weighted;
 
 	// Use the operation family to choose the one of the two matrices
 	// being partitioned that potentially has structure, and also to
@@ -969,7 +969,7 @@ siz_t bli_thread_range_weighted_b2t
 void bli_prime_factorization( dim_t n, bli_prime_factors_t* factors )
 {
     factors->n = n;
-    factors->sqrt_n = (dim_t)sqrt(n);
+    factors->sqrt_n = ( dim_t )sqrt( ( double )n );
     factors->f = 2;
 }
 
@@ -1040,26 +1040,38 @@ dim_t bli_next_prime_factor( bli_prime_factors_t* factors )
     return tmp;
 }
 
-void bli_partition_2x2( dim_t nthread, dim_t work1, dim_t work2,
-                        dim_t* nt1, dim_t* nt2 )
+#if 0
+#include "limits.h"
+#endif
+
+void bli_thread_partition_2x2
+     (
+       dim_t           n_thread,
+       dim_t           work1,
+       dim_t           work2,
+       dim_t* restrict nt1,
+       dim_t* restrict nt2
+     )
 {
     // Partition a number of threads into two factors nt1 and nt2 such that
     // nt1/nt2 ~= work1/work2. There is a fast heuristic algorithm and a
     // slower optimal algorithm (which minimizes |nt1*work2 - nt2*work1|).
 
     // Return early small prime numbers of threads.
-    if (nthread < 4)
+    if ( n_thread < 4 )
     {
-        *nt1 = ( work1 >= work2 ? nthread : 1 );
-        *nt2 = ( work1 <  work2 ? nthread : 1 );
+        *nt1 = ( work1 >= work2 ? n_thread : 1 );
+        *nt2 = ( work1 <  work2 ? n_thread : 1 );
+
+		return;
     }
 
     *nt1 = 1;
     *nt2 = 1;
 
-    // Both algorithms need the prime factorization of nthread.
+    // Both algorithms need the prime factorization of n_thread.
     bli_prime_factors_t factors;
-    bli_prime_factorization( nthread, &factors );
+    bli_prime_factorization( n_thread, &factors );
 
     #if 1
 
@@ -1086,10 +1098,10 @@ void bli_partition_2x2( dim_t nthread, dim_t work1, dim_t work2,
 
     #else
 
-    // Slow algorithm: exhaustively constructs all factor pairs of nthread and
+    // Slow algorithm: exhaustively constructs all factor pairs of n_thread and
     // chooses the best one.
 
-    // Eight prime factors handles nthread up to 223092870.
+    // Eight prime factors handles n_thread up to 223092870.
     dim_t fact[8];
     dim_t mult[8];
 
@@ -1123,7 +1135,7 @@ void bli_partition_2x2( dim_t nthread, dim_t work1, dim_t work2,
     // Loop over how many prime factors to assign to the first factor in the
     // pair, for each prime factor. The total number of iterations is
     // \Prod_{i=0}^{nfact-1} mult[i].
-    bool done = false;
+    bool   done = FALSE;
     while ( !done )
     {
         dim_t x = 1;
@@ -1152,7 +1164,7 @@ void bli_partition_2x2( dim_t nthread, dim_t work1, dim_t work2,
             if ( ++ntake[i] > mult[i] )
             {
                 ntake[i] = 0;
-                if ( i == nfact-1 ) done = true;
+                if ( i == nfact-1 ) done = TRUE;
                 else continue;
             }
             break;
@@ -1284,6 +1296,7 @@ void bli_thread_init_rntm_from_env
 	// function is only called from bli_thread_init(), which is only called
 	// by bli_init_once().
 
+	bool  auto_factor = FALSE;
 	dim_t nt;
 	dim_t jc, pc, ic, jr, ir;
 
@@ -1306,8 +1319,8 @@ void bli_thread_init_rntm_from_env
 
 	// If any BLIS_*_NT environment variable was set, then we ignore the
 	// value of BLIS_NUM_THREADS or OMP_NUM_THREADS and use the
-	// BLIS_*_NT values instead (with unset variables being assumed to
-	// contain 1).
+	// BLIS_*_NT values instead (with unset variables being treated as if
+	// they contained 1).
 	if ( jc != -1 || pc != -1 || ic != -1 || jr != -1 || ir != -1 )
 	{
 		if ( jc == -1 ) jc = 1;
@@ -1320,9 +1333,14 @@ void bli_thread_init_rntm_from_env
 		nt = -1;
 	}
 
-	// By this time, either nt is set and the ways for each loop
-	// are all unset, OR nt is unset and the ways for each loop
-	// are all set.
+	// By this time, one of the following conditions holds:
+	// - nt is -1 and the ways for each loop are -1.
+	// - nt is -1 and the ways for each loop are all set.
+	// - nt is set and the ways for each loop are -1.
+
+	// If nt is set (ie: not -1), then we know we will perform an automatic
+	// thread factorization (later, in bli_rntm.c).
+	if ( nt != -1 ) auto_factor = TRUE;
 
 #else
 
@@ -1334,6 +1352,7 @@ void bli_thread_init_rntm_from_env
 #endif
 
 	// Save the results back in the runtime object.
+	bli_rntm_set_auto_factor_only( auto_factor, rntm );
 	bli_rntm_set_num_threads_only( nt, rntm );
 	bli_rntm_set_ways_only( jc, pc, ic, jr, ir, rntm );
 
