@@ -43,9 +43,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -192,9 +192,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -349,9 +349,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -514,9 +514,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -687,9 +687,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -868,9 +868,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -1057,9 +1057,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
@@ -1254,9 +1254,9 @@ void PASTEMAC3(ch,opname,arch,suf) \
        dim_t            cdim, \
        dim_t            n, \
        dim_t            n_max, \
-       void*   restrict kappa, \
-       void*   restrict a, inc_t inca, inc_t lda, \
-       void*   restrict p, inc_t is_p, inc_t ldp, \
+       ctype*  restrict kappa, \
+       ctype*  restrict a, inc_t inca, inc_t lda, \
+       ctype*  restrict p, inc_t is_p, inc_t ldp, \
        cntx_t* restrict cntx  \
      ) \
 { \
