@@ -5,7 +5,7 @@
    libraries.
 
    Copyright (C) 2014, The University of Texas at Austin
-   Copyright (C) 2018, Advanced Micro Devices, Inc.
+   Copyright (C) 2018 - 2019, Advanced Micro Devices, Inc.
 
    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions are
@@ -264,15 +264,25 @@ void libblis_test_trsm_ukr_experiment
 #endif
 
 	// Create the packed objects. Use packmr and packnr as the leading
-	// dimensions of ap and bp, respectively.
-	bli_obj_create( datatype, m, m, 1, ldap, &ap );
-	bli_obj_create( datatype, m, n, ldbp, 1, &bp );
+	// dimensions of ap and bp, respectively. Note that we use the ldims
+	// instead of the matrix dimensions for allocation purposes here.
+	// This is a little hacky and was prompted when trying to support
+	// configurations such as power9 that employ duplication/broadcasting
+	// of elements in one of the packed matrix objects. Thankfully, packm
+	// doesn't care about those dimensions and instead relies on
+	// information taken from the source object. Thus, this is merely
+	// about coaxing bli_obj_create() in allocating enough space for our
+	// purposes.
+	bli_obj_create( datatype, ldap, m, 1, ldap, &ap );
+	bli_obj_create( datatype, m, ldbp, ldbp, 1, &bp );
 
 	// Set up the objects for packing. Calling packm_init_pack() does everything
 	// except checkout a memory pool block and save its address to the obj_t's.
 	// However, it does overwrite the buffer field of packed object with that of
-	// the source object. So, we have to save the buffer address that was
-	// allocated.
+	// the source object (as a side-effect of bli_obj_alias_to(); that buffer
+	// field would normally be overwritten yet again by the address from the
+	// memory pool block). So, we have to save the buffer address that was
+	// allocated so we can re-store it to the object afterward.
 	void* buf_ap = bli_obj_buffer( &ap );
 	void* buf_bp = bli_obj_buffer( &bp );
 	bli_packm_init_pack( BLIS_INVERT_DIAG, BLIS_PACKED_ROW_PANELS,
@@ -336,6 +346,10 @@ bli_printm( "ap", &ap, "%5.2f", "" );
 	bli_cntl_free( NULL, cntl_b, &BLIS_PACKM_SINGLE_THREADED );
 #endif
 
+	// Free the packed objects.
+	bli_obj_free( &ap );
+	bli_obj_free( &bp );
+
 	// Free the test objects.
 	bli_obj_free( &a );
 	bli_obj_free( &b );
@@ -401,7 +415,7 @@ void libblis_test_trsm_ukr_check
 	//
 	// is functioning correctly if
 	//
-	//   normf( v - z )
+	//   normfv( v - z )
 	//
 	// is negligible, where
 	//
